Computation times — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# Computation times

00:30.393 total execution time for 5 files from examples01-dos:

Example | Time | Mem (MB)
--- | --- | ---
Plotting non colinear dos in Quantum Espresso (`plot_noncolinear_dos_qe.py`) | 00:17.196 | 0.0
Plotting density of states (`plot_colinear_dos.py`) | 00:04.406 | 0.0
Plotting non colinear dos in VASP (`plot_noncolinear_dos_vasp.py`) | 00:04.373 | 0.0
Plotting spin-polarized density of states (`plot_spin_polarized_dos.py`) | 00:03.161 | 0.0
Plotting with Configurations in pyprocar (`plot_dosplot_configurations.py`) | 00:01.257 | 0.0